class QueryWords:

    weights = [4, 4, 4, 3, 3, 2, 2, 1, 1, 1]

    def __init__(self, query: str, language_dict: dict) -> None:
        query_list = query.lower().split(" ")

        # Convertir listas de palabras a conjuntos para búsquedas rápidas
        dict_sets = {key: set(words) for key, words in language_dict.items()}

        # Inicializar listas para cada categoría
        names = []
        verbs = []
        nouns = []
        adverbs = []
        adjectives = []
        pronouns = []
        determiners = []
        prepositions = []
        interjections = []
        conjunctions = []

        # Clasificar palabras en categorías
        for word in query_list:
            for category in dict_sets:
                if word in dict_sets[category]:
                    locals()[category].append(word)
                    break
            else:
                names.append(word)

        # Lista de listas de palabras
        self.words = [
            names,
            verbs,
            nouns,
            adverbs,
            adjectives,
            pronouns,
            determiners,
            prepositions,
            interjections,
            conjunctions
        ]

        # Suponiendo que `self.weights` se define en otro lugar y corresponde a la longitud de `self.words`
        word_weights = [
            {word: self.weights[i] for word in words}
            for i, words in enumerate(self.words)
        ]

        # Calcular el puntaje máximo
        self.max_score = sum(
            weight
            for words in word_weights
            for weight in words.values()
        )

language_dict = {
    "verbs": ["hacer"],
    "adverbs": ["como"],
    "determiners": ["un"],
    "interjections": ["y"]
}

query = "Como"

query_words = QueryWords(query, language_dict)

print(query_words.max_score)


from setuptools import find_packages, setup
from os import path

def read(fname):
    with open(path.join(path.dirname(__file__), fname), encoding="utf-8") as f:
        return f.read()

def main():
    setup(
        name="VideoService",
        version="0.1.2",
        description="A library to create video services",
        package_dir={"": "VideoService"},
        packages=find_packages(where=["VideoService"]),
        long_description=read("README.md"),
        long_description_content_type="text/markdown",
        url="https://github.com/Dtar380/VideoService",
        author="Dtar380",
        license="MIT",
        project_urls={
            "Homepage": "https://github.com/Dtar380/VideoService",
            "Documentation": "https://github.com/Dtar380/VideoService/blob/main/README.md",
            "Repository": "https://github.com/Dtar380/VideoService"
        },
        classifiers=[
            "Development Status :: 4 - Beta",

            "Intended Audience :: Developers",

            "Topic :: Database :: Database Engines/Servers",
            "Topic :: Office/Business",
            "Topic :: Multimedia :: Video",

            "Operating System :: OS Independent",

            "License :: OSI Approved :: MIT License",

            "Programming Language :: Python :: 3",
            "Programming Language :: Python :: 3.8",
            "Programming Language :: Python :: 3.9",
            "Programming Language :: Python :: 3.10",
            "Programming Language :: Python :: 3.11",
            "Programming Language :: Python :: 3.12"
        ],
        install_requires=[read("requirements.txt").splitlines()],
        extra_requires={
            "dev": ["pytest>=8.0.0", "twine>=5.0.0"]
        },
        python_requires=">=3.8"
    )

if __name__ == "__main__":
    main()



from typing import Union, Dict, List
from types import TracebackType

settings = {
    "_filter_by_date": {
        "filter": list[str],
        "active": True | False
    },
    "_filter_by_length": {
        "filter": list[int],
        "active": True | False
    },
    "_filter_by_tags": {
        "filter": list[str],
        "active": True | False
    }}

Expected_type = Dict[str, Dict[str, Union[ Union[ List[str], list[int] ], bool] ] ]

print(isinstance(settings, Expected_type))